package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.log.annotation.Log;
import com.usky.common.log.enums.BusinessType;
import com.usky.fire.domain.DemWaterSource;
import com.usky.fire.service.DemWaterSourceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
 * 水源信息表 前端控制器
 * </p>
 *
 * @author JCB
 * @since 2022-10-24
 */
@RestController
@RequestMapping("/demWaterSource")
public class DemWaterSourceController {

    @Autowired
    private DemWaterSourceService demWaterSourceService;

    /**
     * 消防水源管理-列表
     *
     * @param waterName 水源名称
     * @param id        主键ID
     * @param pageNum   当前页
     * @param pageSize  每页条数
     * @return
     */
    @GetMapping("waterSourceList")
    public ApiResult<CommonPage<Map<String, Object>>> waterSourceList(@RequestParam(value = "waterName", required = false) String waterName,
                                                                      @RequestParam(value = "id", required = false, defaultValue = "0") Integer id,
                                                                      @RequestParam(value = "pageNum", required = false, defaultValue = "1") Integer pageNum,
                                                                      @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize) {
        return ApiResult.success(demWaterSourceService.waterSourceList(waterName, id, pageNum, pageSize));
    }

    /**
     * 消防水源管理-修改
     *
     * @param demWaterSource
     */
    @Log(title = "消防水源管理-修改", businessType = BusinessType.UPDATE)
    @PutMapping("updateWaterSource")
    public ApiResult<Void> updateWaterSource(@RequestBody DemWaterSource demWaterSource) {
        demWaterSourceService.updateWaterSource(demWaterSource);
        return ApiResult.success();
    }

    /**
     * 消防水源管理-删除
     *
     * @param id 主键ID
     */
    @Log(title = "消防水源管理-删除", businessType = BusinessType.DELETE)
    @DeleteMapping("delWaterSource")
    public ApiResult<Void> delWaterSource(@RequestParam(value = "id") Integer id) {
        demWaterSourceService.delWaterSource(id);
        return ApiResult.success();
    }
}

